asr.core
========

.. automodule:: asr.core

   
   
   .. rubric:: Functions

   
   .. autofunction:: add_param
   .. autofunction:: argument
   .. autofunction:: chdir
   .. autofunction:: command
   .. autofunction:: encode_json
   .. autofunction:: file_barrier
   .. autofunction:: get_dep_tree
   .. autofunction:: get_dimensionality
   .. autofunction:: get_recipe_from_name
   .. autofunction:: get_recipe_module_names
   .. autofunction:: get_recipe_modules
   .. autofunction:: get_recipes
   .. autofunction:: is_magnetic
   .. autofunction:: magnetic_atoms
   .. autofunction:: md5sum
   .. autofunction:: option
   .. autofunction:: paramerrormsg
   .. autofunction:: parse_dict_string
   .. autofunction:: parse_mod_func
   .. autofunction:: read_json
   .. autofunction:: recursive_update
   .. autofunction:: singleprec_dict
   .. autofunction:: unlink
   .. autofunction:: write_json
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: ASRCommand
   
   

   
   
   